# set max parallel build nodes
%global _smp_ncpus_max 6

Name:           vcmi
Version:        0.99
Release:        %mkrel 4
Summary:        Open-source reimplementation and extension of the Heroes III game engine
Group:          Games/Strategy
License:        GPLv2+
URL:            http://www.vcmi.eu/
Source0:        https://github.com/vcmi/vcmi/archive/%{version}/%{name}-%{version}.tar.gz

BuildRequires:  boost-devel
BuildRequires:  cmake
BuildRequires:  fuzzylite-devel
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libswscale)
BuildRequires:  pkgconfig(minizip)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(SDL2_image)
BuildRequires:  pkgconfig(SDL2_mixer)
BuildRequires:  pkgconfig(SDL2_ttf)
BuildRequires:  pkgconfig(zlib)

%description
VCMI is an open-source project aiming to reimplement the Heroes of Might and
Magic III: In the Wake of Gods game engine, giving it new and extended
possibilities.

To play Heroes III, you will need a copy of the original game.
See VCMI's wiki for Heroes III installation instructions:
http://wiki.vcmi.eu/index.php?title=Installation_on_Linux#Installing_Heroes_III_data_files

%files
%doc README.md README.linux AUTHORS ChangeLog
%{_datadir}/applications/%{name}*.desktop
%{_iconsdir}/hicolor/*/apps/%{name}client.png
%{_libdir}/%{name}/
%{_gamesbindir}/%{name}*
%{_gamesdatadir}/%{name}/

#----------------------------------------------------------------------------

%prep
%setup -q
%autopatch -p1

%build
%cmake -DBIN_DIR=games \
       -DDATA_DIR=share/games/%{name} \
       -DLIB_DIR=%{_lib}/%{name} \
       -DCMAKE_INSTALL_LIBDIR=%{_lib} \
       -DCMAKE_SKIP_RPATH=OFF
%make_build

%install
%make_install -C build


%changelog
* Tue May 02 2017 akien <akien> 0.99-4.mga6
+ Revision: 1098380
- Rebuild for ffmpeg 3.3
- Rebuild for fuzzylite 6.0

* Wed Mar 08 2017 akien <akien> 0.99-2.mga6
+ Revision: 1090260
- Rebuild for ffmpeg 3.2.4

* Thu Nov 03 2016 akien <akien> 0.99-1.mga6
+ Revision: 1065026
- Version 0.99

* Tue Jan 12 2016 akien <akien> 0.98-5.20160110.1.mga6
+ Revision: 922248
- Build a dev snapshot to try to bypass boost/stl conflict

  + daviddavid <daviddavid>
    - rebuild for new boost 1.60.0

* Sun Sep 27 2015 fwang <fwang> 0.98-3.mga6
+ Revision: 884095
- rebuild for new boost

* Thu Aug 13 2015 daviddavid <daviddavid> 0.98-1.mga6
+ Revision: 864515
- new version: 0.98
- update Source URL
- add upstream patch to fix building with Boost 1.58
  * https://github.com/vcmi/vcmi/commit/aa00fdbd0e99b2beec382c7677a64d962b748dcb
- rebuild for new boost-1.58.0

* Fri Nov 14 2014 akien <akien> 0.97-2.mga5
+ Revision: 797012
- Rebuild for ffmpeg 2.4

* Sun Nov 02 2014 akien <akien> 0.97-1.mga5
+ Revision: 795283
- Version 0.97
- Now uses SDL2
- Limit parallel build to prevent compiler crash

  + umeabot <umeabot>
    - Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.96-2.mga5
+ Revision: 690137
- Mageia 5 Mass Rebuild

* Mon Jul 14 2014 akien <akien> 0.96-1.mga5
+ Revision: 651795
- Version 0.96

* Sun Mar 23 2014 akien <akien> 0.95-5.mga5
+ Revision: 607041
- CMAKE_INSTALL_LIBDIR has to be a relative path for CMakeLists.txt

* Sun Mar 23 2014 akien <akien> 0.95-4.mga5
+ Revision: 606731
- Undefine rpath skipping (needed so that the libs can be linked)

* Sat Mar 22 2014 akien <akien> 0.95-3.mga5
+ Revision: 606628
- Specify library location

* Sat Mar 22 2014 akien <akien> 0.95-2.mga5
+ Revision: 606553
- Put the runtime libraries in %%_libdir, it seems they cannot be found in %%_libexecdic

* Fri Mar 21 2014 akien <akien> 0.95-1.mga5
+ Revision: 606414
- imported package vcmi

